@@ -69,8 +69,8 @@ class ApiClient(AuthenticatedClient):
         if require_api_key:
             if config.api_key is None:
                 raise AuthenticationException(
-                    "API key is required, please visit the Team tab at https://agentbox.lingyiwanwu.net/dashboard to get your API key. "
-                    "You can either set the environment variable `E2B_API_KEY` "
+                    "API key is required, please visit the Team tab at https://agentbox.space/dashboard to get your API key. "
+                    "You can either set the environment variable `AGENTBOX_API_KEY` "
                     'or you can pass it directly to the sandbox like Sandbox(api_key="e2b_...")',
                 )
             token = config.api_key
@@ -78,8 +78,8 @@ class ApiClient(AuthenticatedClient):
         if require_access_token:
             if config.access_token is None:
                 raise AuthenticationException(
-                    "Access token is required, please visit the Personal tab at https://agentbox.lingyiwanwu.net/dashboard to get your access token. "
-                    "You can set the environment variable `E2B_ACCESS_TOKEN` or pass the `access_token` in options.",
+                    "Access token is required, please visit the Personal tab at https://agentbox.space/dashboard to get your access token. "
+                    "You can set the environment variable `AGENTBOX_ACCESS_TOKEN` or pass the `access_token` in options.",
                 )
             token = config.access_token
 
